@@ -296,6 +296,7 @@
 #define STRING_CMD_INFO_UNTIL        "Bis"
 #define STRING_CMD_INFO_MODIFICATION "Änderung"
 #define STRING_CMD_INFO_MODIFIED     "Letzte Änderung"
+#define STRING_CMD_INFO_VIRTUAL_TAGS "Virtual tags"
 #define STRING_CMD_UNDO_USAGE        "Macht die letzte Änderung an einer Aufgabe Rückgängig"
 #define STRING_CMD_UNDO_MODS         "Der undo-Befehl erlaubt keine weitere Aufgaben-Änderung."
 #define STRING_CMD_STATS_USAGE       "Zeigt Statistiken zur Aufgaben-Datenbank"
@@ -561,6 +562,25 @@
 #define STRING_CMD_CONFIG_NO_CHANGE  "Keine Änderungen durchgeführt."
 #define STRING_CMD_CONFIG_NO_NAME    "Geben Sie den Wert der zu ändernden Option an."
 #define STRING_CMD_HCONFIG_USAGE     "Zeigt alle unterstützten Konfigurations-Optionen zur AUtovervollständigung"
+#define STRING_CMD_CONTEXT_USAGE     "Set and define contexts (default filters)"
+#define STRING_CMD_CONTEXT_DEF_SUCC  "Context '{1}' defined."
+#define STRING_CMD_CONTEXT_DEF_FAIL  "Context '{1}' not defined."
+#define STRING_CMD_CONTEXT_DEF_USAG  "Both context name and its definition must be provided."
+#define STRING_CMD_CONTEXT_DEF_ABRT  "Context definiton aborted."
+#define STRING_CMD_CONTEXT_DEF_ABRT2 "Filter validation failed: {1}"
+#define STRING_CMD_CONTEXT_DEF_CONF  "The filter '{1}' matches 0 pending tasks. Do you wish to continue?"
+#define STRING_CMD_CONTEXT_DEL_SUCC  "Context '{1}' deleted."
+#define STRING_CMD_CONTEXT_DEL_FAIL  "Context '{1}' not deleted."
+#define STRING_CMD_CONTEXT_DEL_USAG  "Context name needs to be specified."
+#define STRING_CMD_CONTEXT_LIST_EMPT "No contexts defined."
+#define STRING_CMD_CONTEXT_SET_NFOU  "Context '{1}' not found."
+#define STRING_CMD_CONTEXT_SET_SUCC  "Context '{1}' set. Use 'task context none' to remove."
+#define STRING_CMD_CONTEXT_SET_FAIL  "Context '{1}' not applied."
+#define STRING_CMD_CONTEXT_SHOW_EMPT "No context is currently applied."
+#define STRING_CMD_CONTEXT_SHOW      "Context '{1}' with filter '{2}' is currently applied."
+#define STRING_CMD_CONTEXT_NON_SUCC  "Context unset."
+#define STRING_CMD_CONTEXT_NON_FAIL  "Context not unset."
+#define STRING_CMD_HCONTEXT_USAGE    "Lists all supported contexts, for completion purposes"
 #define STRING_CMD_CUSTOM_MISMATCH   "Die Anzahl von Spalten und Beschriftungen für Report '{1}' unterscheidet sich."
 #define STRING_CMD_CUSTOM_SHOWN      "{1} gezeigt"
 #define STRING_CMD_CUSTOM_COUNT      "1 Aufgabe"
@@ -881,10 +901,6 @@
 #define STRING_TDB2_UNDO_SYNCED      "Kann Änderung nicht rückgängig machen, weil die Aufgabe bereits abgeglichen wurde.  Aufgabe stattdessen löschen."
 #define STRING_TDB2_DIRTY_EXIT       "Beende mit ungeschriebenen Änderungen auf {1}"
 
-// utf8
-#define STRING_UTF8_INVALID_CP_REP   "Ungültige Codepoint-Darstellung."
-#define STRING_UTF8_INVALID_CP       "Ungültiger Unicode-Codepoint."
-
 // View
 #define STRING_VIEW_TOO_SMALL        "Dieser Report hat eine Mindestbreite von {1} und passt nicht in die Bildschirmbreite von {2}."
 
