@@ -298,6 +298,7 @@
 #define STRING_CMD_INFO_UNTIL        "Hasta"
 #define STRING_CMD_INFO_MODIFICATION "Modificación"
 #define STRING_CMD_INFO_MODIFIED     "Modificada por última vez"
+#define STRING_CMD_INFO_VIRTUAL_TAGS "Virtual tags"
 #define STRING_CMD_UNDO_USAGE        "Revierte el cambio más reciente a una tarea"
 #define STRING_CMD_UNDO_MODS         "El comando undo no permite más modificación a la tarea."
 #define STRING_CMD_STATS_USAGE       "Muestra estadísticas de la base de datos de tareas"
@@ -570,6 +571,25 @@
 #define STRING_CMD_CONFIG_NO_CHANGE  "No se hicieron cambios."
 #define STRING_CMD_CONFIG_NO_NAME    "Especifique el nombre de una variable de configuración a modificar."
 #define STRING_CMD_HCONFIG_USAGE     "Lista todas las variables de configuración soportadas, a fines de completado"
+#define STRING_CMD_CONTEXT_USAGE     "Set and define contexts (default filters)"
+#define STRING_CMD_CONTEXT_DEF_SUCC  "Context '{1}' defined."
+#define STRING_CMD_CONTEXT_DEF_FAIL  "Context '{1}' not defined."
+#define STRING_CMD_CONTEXT_DEF_USAG  "Both context name and its definition must be provided."
+#define STRING_CMD_CONTEXT_DEF_ABRT  "Context definiton aborted."
+#define STRING_CMD_CONTEXT_DEF_ABRT2 "Filter validation failed: {1}"
+#define STRING_CMD_CONTEXT_DEF_CONF  "The filter '{1}' matches 0 pending tasks. Do you wish to continue?"
+#define STRING_CMD_CONTEXT_DEL_SUCC  "Context '{1}' deleted."
+#define STRING_CMD_CONTEXT_DEL_FAIL  "Context '{1}' not deleted."
+#define STRING_CMD_CONTEXT_DEL_USAG  "Context name needs to be specified."
+#define STRING_CMD_CONTEXT_LIST_EMPT "No contexts defined."
+#define STRING_CMD_CONTEXT_SET_NFOU  "Context '{1}' not found."
+#define STRING_CMD_CONTEXT_SET_SUCC  "Context '{1}' set. Use 'task context none' to remove."
+#define STRING_CMD_CONTEXT_SET_FAIL  "Context '{1}' not applied."
+#define STRING_CMD_CONTEXT_SHOW_EMPT "No context is currently applied."
+#define STRING_CMD_CONTEXT_SHOW      "Context '{1}' with filter '{2}' is currently applied."
+#define STRING_CMD_CONTEXT_NON_SUCC  "Context unset."
+#define STRING_CMD_CONTEXT_NON_FAIL  "Context not unset."
+#define STRING_CMD_HCONTEXT_USAGE    "Lists all supported contexts, for completion purposes"
 #define STRING_CMD_CUSTOM_MISMATCH   "Hay diferente número de columnas y etiquetas para el informe '{1}'."
 #define STRING_CMD_CUSTOM_SHOWN      "{1} mostrada(s)"
 #define STRING_CMD_CUSTOM_COUNT      "1 tarea"
@@ -891,10 +911,6 @@
 #define STRING_TDB2_UNDO_SYNCED      "No se puede deshacer el cambio porque la tarea ya ha sido sincronizada. Como alternativa, modifique la tarea."
 #define STRING_TDB2_DIRTY_EXIT       "Exiting with unwritten changes to {1}"
 
-// utf8
-#define STRING_UTF8_INVALID_CP_REP   "Representación de codepoint no válida."
-#define STRING_UTF8_INVALID_CP       "Codepoint Unicode no válido."
-
 // View
 #define STRING_VIEW_TOO_SMALL        "El informe tiene una anchura mínima de {1} y no cabe en la disponible, que es {2}."
 
