@@ -296,6 +296,7 @@
 #define STRING_CMD_INFO_UNTIL        "Jusqu'au"
 #define STRING_CMD_INFO_MODIFICATION "Modification"
 #define STRING_CMD_INFO_MODIFIED     "Dernier modifié"
+#define STRING_CMD_INFO_VIRTUAL_TAGS "Virtual tags"
 #define STRING_CMD_UNDO_USAGE        "Annule les changements les plus récents sur une tâche"
 #define STRING_CMD_UNDO_MODS         "The undo command does not allow further task modification."
 #define STRING_CMD_STATS_USAGE       "Affiche les statistiques de la base de donnée"
@@ -561,6 +562,24 @@
 #define STRING_CMD_CONFIG_NO_CHANGE  "No changes made."
 #define STRING_CMD_CONFIG_NO_NAME    "Specify the name of a config variable to modify."
 #define STRING_CMD_HCONFIG_USAGE     "Lists all supported configuration variables, for completion purposes"
+#define STRING_CMD_CONTEXT_USAGE     "Set and define contexts (default filters)"
+#define STRING_CMD_CONTEXT_DEF_SUCC  "Context '{1}' defined."
+#define STRING_CMD_CONTEXT_DEF_FAIL  "Context '{1}' not defined."
+#define STRING_CMD_CONTEXT_DEF_USAG  "Both context name and its definition must be provided."
+#define STRING_CMD_CONTEXT_DEF_ABRT  "Context definiton aborted."
+#define STRING_CMD_CONTEXT_DEF_CONF  "The filter '{1}' matches 0 pending tasks. Do you wish to continue?"
+#define STRING_CMD_CONTEXT_DEL_SUCC  "Context '{1}' deleted."
+#define STRING_CMD_CONTEXT_DEL_FAIL  "Context '{1}' not deleted."
+#define STRING_CMD_CONTEXT_DEL_USAG  "Context name needs to be specified."
+#define STRING_CMD_CONTEXT_LIST_EMPT "No contexts defined."
+#define STRING_CMD_CONTEXT_SET_NFOU  "Context '{1}' not found."
+#define STRING_CMD_CONTEXT_SET_SUCC  "Context '{1}' set. Use 'task context none' to remove."
+#define STRING_CMD_CONTEXT_SET_FAIL  "Context '{1}' not applied."
+#define STRING_CMD_CONTEXT_SHOW_EMPT "No context is currently applied."
+#define STRING_CMD_CONTEXT_SHOW      "Context '{1}' with filter '{2}' is currently applied."
+#define STRING_CMD_CONTEXT_NON_SUCC  "Context unset."
+#define STRING_CMD_CONTEXT_NON_FAIL  "Context not unset."
+#define STRING_CMD_HCONTEXT_USAGE    "Lists all supported contexts, for completion purposes"
 #define STRING_CMD_CUSTOM_MISMATCH   "There are different numbers of columns and labels for report '{1}'."
 #define STRING_CMD_CUSTOM_SHOWN      "{1} affichées"
 #define STRING_CMD_CUSTOM_COUNT      "1 tâche"
@@ -881,10 +900,6 @@
 #define STRING_TDB2_UNDO_SYNCED      "Impossible d'annuler les changements car la tâche a déjà été synchronysée. Modifiez plutôt la tâche."
 #define STRING_TDB2_DIRTY_EXIT       "Exiting with unwritten changes to {1}"
 
-// utf8
-#define STRING_UTF8_INVALID_CP_REP   "Invalid codepoint representation."
-#define STRING_UTF8_INVALID_CP       "Invalid Unicode codepoint."
-
 // View
 #define STRING_VIEW_TOO_SMALL        "The report has a minimum width of {1} and does not fit in the available width of {2}."
 
