@@ -295,6 +295,7 @@
 #define STRING_CMD_INFO_UNTIL        "Fino a"
 #define STRING_CMD_INFO_MODIFICATION "Modifica"
 #define STRING_CMD_INFO_MODIFIED     "Ultima modifica"
+#define STRING_CMD_INFO_VIRTUAL_TAGS "Virtual tags"
 #define STRING_CMD_UNDO_USAGE        "Ritorna alla più recente modifica di un task"
 #define STRING_CMD_UNDO_MODS         "Il comando undo non ammette ulteriori modifiche al task."
 #define STRING_CMD_STATS_USAGE       "Mostra le statistiche sul task"
@@ -560,6 +561,25 @@
 #define STRING_CMD_CONFIG_NO_CHANGE  "Nessuna modifica apportata."
 #define STRING_CMD_CONFIG_NO_NAME    "Specificare il nome di una variabile di configurazione da modificare."
 #define STRING_CMD_HCONFIG_USAGE     "Elenca le variabili di configurazione supportate, per autocompletamento"
+#define STRING_CMD_CONTEXT_USAGE     "Set and define contexts (default filters)"
+#define STRING_CMD_CONTEXT_DEF_SUCC  "Context '{1}' defined."
+#define STRING_CMD_CONTEXT_DEF_FAIL  "Context '{1}' not defined."
+#define STRING_CMD_CONTEXT_DEF_USAG  "Both context name and its definition must be provided."
+#define STRING_CMD_CONTEXT_DEF_ABRT  "Context definiton aborted."
+#define STRING_CMD_CONTEXT_DEF_ABRT2 "Filter validation failed: {1}"
+#define STRING_CMD_CONTEXT_DEF_CONF  "The filter '{1}' matches 0 pending tasks. Do you wish to continue?"
+#define STRING_CMD_CONTEXT_DEL_SUCC  "Context '{1}' deleted."
+#define STRING_CMD_CONTEXT_DEL_FAIL  "Context '{1}' not deleted."
+#define STRING_CMD_CONTEXT_DEL_USAG  "Context name needs to be specified."
+#define STRING_CMD_CONTEXT_LIST_EMPT "No contexts defined."
+#define STRING_CMD_CONTEXT_SET_NFOU  "Context '{1}' not found."
+#define STRING_CMD_CONTEXT_SET_SUCC  "Context '{1}' set. Use 'task context none' to remove."
+#define STRING_CMD_CONTEXT_SET_FAIL  "Context '{1}' not applied."
+#define STRING_CMD_CONTEXT_SHOW_EMPT "No context is currently applied."
+#define STRING_CMD_CONTEXT_SHOW      "Context '{1}' with filter '{2}' is currently applied."
+#define STRING_CMD_CONTEXT_NON_SUCC  "Context unset."
+#define STRING_CMD_CONTEXT_NON_FAIL  "Context not unset."
+#define STRING_CMD_HCONTEXT_USAGE    "Lists all supported contexts, for completion purposes"
 #define STRING_CMD_CUSTOM_MISMATCH   "Differente numero di colonne ed etichette per il report '{1}'."
 #define STRING_CMD_CUSTOM_SHOWN      "{1} mostrato"
 #define STRING_CMD_CUSTOM_COUNT      "1 task"
@@ -880,10 +900,6 @@
 #define STRING_TDB2_UNDO_SYNCED      "Cannot undo change because the task was already synced.  Modify the task instead."
 #define STRING_TDB2_DIRTY_EXIT       "Exiting with unwritten changes to {1}"
 
-// utf8
-#define STRING_UTF8_INVALID_CP_REP   "Rappresentazione non valida del codepoint."
-#define STRING_UTF8_INVALID_CP       "Codepoint Unicode non valido."
-
 // View
 #define STRING_VIEW_TOO_SMALL        "Il report ha larghezza minima di {1} e non entra nella larghezza disponibile di {2}."
 
