@@ -296,6 +296,7 @@
 #define STRING_CMD_INFO_UNTIL        "Até"
 #define STRING_CMD_INFO_MODIFICATION "Modificação"
 #define STRING_CMD_INFO_MODIFIED     "Última modificação"
+#define STRING_CMD_INFO_VIRTUAL_TAGS "Virtual tags"
 #define STRING_CMD_UNDO_USAGE        "Reverte a mais recente modificação a uma tarefa"
 #define STRING_CMD_UNDO_MODS         "O comando undo não permite outras modificações simultâneas."
 #define STRING_CMD_STATS_USAGE       "Exibe estatísticas da base de dados de tarefas"
@@ -561,6 +562,25 @@
 #define STRING_CMD_CONFIG_NO_CHANGE  "Nenhuma alteração efectuada."
 #define STRING_CMD_CONFIG_NO_NAME    "Especifique o nome da configuração a modificar."
 #define STRING_CMD_HCONFIG_USAGE     "Lista todas as configurações suportadas, para fins de terminação automática"
+#define STRING_CMD_CONTEXT_USAGE     "Set and define contexts (default filters)"
+#define STRING_CMD_CONTEXT_DEF_SUCC  "Context '{1}' defined."
+#define STRING_CMD_CONTEXT_DEF_FAIL  "Context '{1}' not defined."
+#define STRING_CMD_CONTEXT_DEF_USAG  "Both context name and its definition must be provided."
+#define STRING_CMD_CONTEXT_DEF_ABRT  "Context definiton aborted."
+#define STRING_CMD_CONTEXT_DEF_ABRT2 "Filter validation failed: {1}"
+#define STRING_CMD_CONTEXT_DEF_CONF  "The filter '{1}' matches 0 pending tasks. Do you wish to continue?"
+#define STRING_CMD_CONTEXT_DEL_SUCC  "Context '{1}' deleted."
+#define STRING_CMD_CONTEXT_DEL_FAIL  "Context '{1}' not deleted."
+#define STRING_CMD_CONTEXT_DEL_USAG  "Context name needs to be specified."
+#define STRING_CMD_CONTEXT_LIST_EMPT "No contexts defined."
+#define STRING_CMD_CONTEXT_SET_NFOU  "Context '{1}' not found."
+#define STRING_CMD_CONTEXT_SET_SUCC  "Context '{1}' set. Use 'task context none' to remove."
+#define STRING_CMD_CONTEXT_SET_FAIL  "Context '{1}' not applied."
+#define STRING_CMD_CONTEXT_SHOW_EMPT "No context is currently applied."
+#define STRING_CMD_CONTEXT_SHOW      "Context '{1}' with filter '{2}' is currently applied."
+#define STRING_CMD_CONTEXT_NON_SUCC  "Context unset."
+#define STRING_CMD_CONTEXT_NON_FAIL  "Context not unset."
+#define STRING_CMD_HCONTEXT_USAGE    "Lists all supported contexts, for completion purposes"
 #define STRING_CMD_CUSTOM_MISMATCH   "O número de colunas e de rótulos não é o mesmo no relatório '{1}'."
 #define STRING_CMD_CUSTOM_SHOWN      "{1} visiveis"
 #define STRING_CMD_CUSTOM_COUNT      "1 tarefa"
@@ -881,10 +901,6 @@
 #define STRING_TDB2_UNDO_SYNCED      "Não é possível reverter a alteração porque a tarefa já foi syncronizada. Em vez disso modifique a tarefa."
 #define STRING_TDB2_DIRTY_EXIT       "Saindo com modificações por gravar de {1}"
 
-// utf8
-#define STRING_UTF8_INVALID_CP_REP   "Representação de 'codepoint' inválida."
-#define STRING_UTF8_INVALID_CP       "'Codepoint' Unicode inválido."
-
 // View
 #define STRING_VIEW_TOO_SMALL        "O relatório tem uma largura mínima de {1} e não cabe na largura disponível {2}."
 
